@@ -100,12 +100,9 @@ def add_ldap_group(groupName, groupDescription, gidNumber):
         attrs['gidNumber'] = str(gidNumber)
         attrs['description'] = groupDescription
         ldif = ldap.modlist.addModlist(attrs)
-        print "adding group with dn: " + dn
-
         l.add_s(dn, ldif)
 
-
-def del_ldap_group(groupName):
+def delete_ldap_group(groupName):
         hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
         hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
         hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
@@ -265,4 +262,6 @@ def userInGroup(userName, groupName):
         if groupName in groups:
                 return True
 
-        return False
\ No newline at end of file
+        return False
+
+
