@@ -226,7 +226,7 @@ def _insert_jos_core_acl_groups_aro_map(db, jgidNumber, aroID):
     db.query_rowcount(sql, data)
 
 
-def _insert_jos_xprofiles(db, hubname, uid, fname, mname, lname, username, email, password, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir):
+def _insert_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, username, email, password, gid, gidNumber, loginShell, homeDir):
 
     if password != '*':
         pw = hubzero.config.passwords.MD5PasswordHash(password)
@@ -241,7 +241,7 @@ def _insert_jos_xprofiles(db, hubname, uid, fname, mname, lname, username, email
     sql += "`proxyPassword`, `proxyUidNumber`, `givenName`, `middleName`, `surname`, `picture`, `vip`, `public`, `params`, `note`, `shadowExpire`) "
     sql += "VALUES (" + '%s,'*37 + "%s );" 
 
-    data = (uid, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
+    data = (uidNumber, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
             '/usr/lib/sftp-server', pw, gid, '', '', '', '', '', '', '', 
             0, 0, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
             '', '', fname, mname, lname, '', 0, 0, '', '', None)
@@ -401,15 +401,15 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagidNumber,
             gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, username, username + " group")	
             gid = username # group name same as user
 
-        uidNumber = _insert_jos_users(db, uid, fullName, username, email, pw, joomlagid, joomlagidNumber)
+        uidNumber = _insert_jos_users(db, -1, fullName, username, email, pw, joomlagidNumber)
         aroID = _insert_jos_core_acl_aro(db, uidNumber, fullName)
         _insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
-        _insert_jos_xprofiles(db, hubname, uidNumber, firstName, middleName, lastName, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir)
+        _insert_jos_xprofiles(db, hubname, uidNumber, firstName, middleName, lastName, username, email, pw, gid, gidNumber, loginShell, homeDir)
         _insert_jos_users_password(db, uidNumber, pw)
 
         # add user to new group (need xgroups insert after user creation because we need userid, I'd prefer to keep all group logic in one place)
         if not skipCreateGroup:
-            hubzero.utilities.group._insert_jos_xgroups_members(db, gidNumber, userID)
+            hubzero.utilities.group._insert_jos_xgroups_members(db, gidNumber, uidNumber)
 
         # create home directory
         if not nocreatehome:
@@ -546,4 +546,4 @@ def getLDAPMaxuidNumber(hubname = ""):
         x = int(result[1]['uidNumber'][0])
         if x > maxid: maxid = x
 
-    return maxid	
\ No newline at end of file
+    return maxid	
